package #
Date::Manip::Offset::off156;
# Copyright (c) 2008-2026 Sullivan Beck.  All rights reserved.
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'tzdata' is run.
#    Generated on: Tue Sep  1 12:20:36 EDT 2026
#    Data version: tzdata2026c
#    Code version: tzcode2026c

# This module contains data from the zoneinfo time zone database.  The original
# data was obtained from the URL:
#    ftp://ftp.iana.org/tz

use strict;
use warnings;
require 5.010000;

our ($VERSION);
$VERSION='7.00';
END { undef $VERSION; }

our ($Offset,%Offset);
END {
   undef $Offset;
   undef %Offset;
}

$Offset        = '+09:00:00';

%Offset        = (
   0 => [
      'asia/tokyo',
      'pacific/palau',
      'asia/pyongyang',
      'asia/seoul',
      'asia/chita',
      'asia/khandyga',
      'asia/yakutsk',
      'asia/jayapura',
      'asia/dili',
      'etc/gmt+9',
      'v',
      'asia/irkutsk',
      'asia/vladivostok',
      'asia/ust-nera',
      'asia/sakhalin',
      'pacific/kosrae',
      'asia/taipei',
      'asia/hong_kong',
      'asia/macau',
      'asia/jakarta',
      'asia/kuching',
      'asia/makassar',
      'asia/manila',
      'asia/pontianak',
      'asia/singapore',
      'asia/yangon',
      'pacific/bougainville',
      'pacific/nauru',
      'asia/ho_chi_minh',
      'pacific/guam',
      'pacific/kwajalein',
      'australia/adelaide',
      'australia/darwin',
      'australia/broken_hill',
      ],
   1 => [
      'asia/ulaanbaatar',
      'asia/irkutsk',
      'australia/perth',
      'asia/shanghai',
      'asia/chita',
      'asia/khandyga',
      'asia/yakutsk',
      'asia/manila',
      'asia/hong_kong',
      'asia/macau',
      'asia/taipei',
      ],
);

1;
