package #
Date::Manip::Offset::off237;
# Copyright (c) 2008-2026 Sullivan Beck.  All rights reserved.
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'tzdata' is run.
#    Generated on: Tue Sep  1 12:20:36 EDT 2026
#    Data version: tzdata2026c
#    Code version: tzcode2026c

# This module contains data from the zoneinfo time zone database.  The original
# data was obtained from the URL:
#    ftp://ftp.iana.org/tz

use strict;
use warnings;
require 5.010000;

our ($VERSION);
$VERSION='7.00';
END { undef $VERSION; }

our ($Offset,%Offset);
END {
   undef $Offset;
   undef %Offset;
}

$Offset        = '-02:00:00';

%Offset        = (
   0 => [
      'atlantic/south_georgia',
      'america/noronha',
      'america/scoresbysund',
      'america/nuuk',
      'etc/gmt-2',
      'b',
      'atlantic/cape_verde',
      'atlantic/azores',
      ],
   1 => [
      'america/miquelon',
      'america/nuuk',
      'america/sao_paulo',
      'america/montevideo',
      'america/araguaina',
      'america/bahia',
      'america/argentina/buenos_aires',
      'america/argentina/cordoba',
      'america/argentina/tucuman',
      'america/argentina/catamarca',
      'america/argentina/jujuy',
      'america/argentina/la_rioja',
      'america/argentina/mendoza',
      'america/argentina/rio_gallegos',
      'america/argentina/salta',
      'america/argentina/san_juan',
      'america/argentina/san_luis',
      'america/argentina/ushuaia',
      'america/fortaleza',
      'america/maceio',
      'america/recife',
      'america/danmarkshavn',
      'america/belem',
      'america/goose_bay',
      'atlantic/stanley',
      'antarctica/palmer',
      ],
);

1;
